package data.scripts.hullmods;

package ..deTemp.1744287149299;

import com.fs.starfarer.api.Global;
import com.fs.starfarer.api.combat.BaseHullMod;
import com.fs.starfarer.api.combat.MutableShipStatsAPI;
import com.fs.starfarer.api.combat.ShipAPI;
import com.fs.starfarer.api.combat.WeaponAPI;
import com.fs.starfarer.api.util.Misc;
import data.scripts.util.MagicIncompatibleHullmods;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class NES_AafArray extends BaseHullMod {
  private static final float ROF_MOD = 50.0F;
  
  private static final float FLUX_MOD = 25.0F;
  
  private static final float ZERO_FLUX_BOOST = 50.0F;
  
  private static final float RANGE_THRESHOLD = 700.0F;
  
  private static final float RANGE_MULT = 0.25F;
  
  private static final float VENT_RATE_BONUS = 25.0F;
  
  private static final Set<String> BLOCKED_HULLMODS = new HashSet<>(2);
  
  static {
    BLOCKED_HULLMODS.add("safetyoverrides");
  }
  
  public void applyEffectsAfterShipCreation(ShipAPI ship, String id) {
    for (String tmp : BLOCKED_HULLMODS) {
      if (ship.getVariant().getHullMods().contains(tmp))
        MagicIncompatibleHullmods.removeHullmodWithWarning(ship.getVariant(), tmp, "NES_AafArray"); 
    } 
  }
  
  public void applyEffectsBeforeShipCreation(ShipAPI.HullSize hullSize, MutableShipStatsAPI stats, String id) {
    stats.getBallisticRoFMult().modifyPercent(id, 50.0F);
    stats.getEnergyRoFMult().modifyPercent(id, 50.0F);
    stats.getBallisticWeaponFluxCostMod().modifyMult(id, 0.75F);
    stats.getEnergyWeaponFluxCostMod().modifyMult(id, 0.75F);
    stats.getBeamWeaponDamageMult().modifyMult(id, 1.05F);
    stats.getZeroFluxSpeedBoost().modifyFlat(id, 50.0F);
    stats.getWeaponRangeThreshold().modifyFlat(id, 700.0F);
    stats.getWeaponRangeMultPastThreshold().modifyMult(id, 0.25F);
    stats.getDynamic().getStat("AMMO_REGEN").modifyMult("NES_AafArray", 1.5F);
    stats.getVentRateMult().modifyPercent(id, 25.0F);
  }
  
  public void advanceInCombat(ShipAPI ship, float amount) {
    if (!ship.isAlive())
      return; 
    if (ship.getFullTimeDeployed() >= 0.5F)
      return; 
    Map<String, Object> customCombatData = Global.getCombatEngine().getCustomData();
    String id = ship.getId();
    if (customCombatData.get("NES_AafArray" + id) instanceof Boolean)
      return; 
    MutableShipStatsAPI stats = ship.getMutableStats();
    for (WeaponAPI w : ship.getAllWeapons()) {
      float BASE_AMMO_REGEN = w.getSpec().getAmmoPerSecond();
      float ammoRegen = 1.0F;
      if (w.getType() == WeaponAPI.WeaponType.BALLISTIC || (w.getType() == WeaponAPI.WeaponType.ENERGY && w.usesAmmo() && BASE_AMMO_REGEN > 0.0F)) {
        ammoRegen *= stats.getDynamic().getStat("AMMO_REGEN").getModifiedValue();
        w.getAmmoTracker().setAmmoPerSecond(w.getAmmoTracker().getAmmoPerSecond() * ammoRegen);
      } 
    } 
    customCombatData.put("NES_AafArray" + id, Boolean.valueOf(true));
  }
  
  public String getDescriptionParam(int index, ShipAPI.HullSize hullSize) {
    if (index == 0)
      return Math.round(50.0F) + "%"; 
    if (index == 1)
      return Math.round(25.0F) + "%"; 
    if (index == 2)
      return "" + Math.round(50.0F); 
    if (index == 3)
      return "25%"; 
    if (index == 4)
      return Misc.getRoundedValue(700.0F); 
    if (index == 5)
      return Global.getSettings().getHullModSpec("safetyoverrides").getDisplayName(); 
    return null;
  }
}
